@@ -1,4 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/*
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
+ */
+
 #ifndef _EAB_MODEL_H_
 #define _EAB_MODEL_H_
 
@@ -24,15 +43,15 @@ struct _EABModel {
 	EBookQuery *query;
 	EBookView *book_view;
 
-	int book_view_idle_id;
+	gint book_view_idle_id;
 
 	EContact **data;
-	int data_count;
-	int allocated_count;
+	gint data_count;
+	gint allocated_count;
 
-	int create_contact_id, remove_contact_id, modify_contact_id;
-	int status_message_id, writable_status_id, sequence_complete_id;
-	int backend_died_id;
+	gint create_contact_id, remove_contact_id, modify_contact_id;
+	gint status_message_id, writable_status_id, sequence_complete_id;
+	gint backend_died_id;
 
 	guint search_in_progress : 1;
 	guint editable : 1;
@@ -40,7 +59,6 @@ struct _EABModel {
 	guint first_get_view : 1;
 };
 
-
 struct _EABModelClass {
 	GObjectClass parent_class;
 
@@ -60,13 +78,12 @@ struct _EABModelClass {
 	void (*backend_died)       (EABModel *model);
 };
 
-
 GType              eab_model_get_type                  (void);
 EABModel          *eab_model_new                       (void);
 
 /* Returns object with ref count of 1. */
 EContact          *eab_model_get_contact               (EABModel *model,
-							int                row);
+							gint                row);
 EBook             *eab_model_get_ebook                 (EABModel *model);
 
 void               eab_model_stop                      (EABModel *model);
@@ -74,9 +91,9 @@ gboolean           eab_model_can_stop                  (EABModel *model);
 
 void               eab_model_force_folder_bar_message  (EABModel *model);
 
-int                eab_model_contact_count             (EABModel *model);
+gint                eab_model_contact_count             (EABModel *model);
 const EContact    *eab_model_contact_at                (EABModel *model,
-							int                index);
+							gint                index);
 gboolean           eab_model_editable                  (EABModel *model);
 
 #endif /* _EAB_MODEL_H_ */
