@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -324,7 +324,7 @@ event_editor_constructor (GType type,
 			event_page_show_options (priv->event_page);
 
 		comp_editor_set_group_item (editor, TRUE);
-  		if (!((flags & COMP_EDITOR_USER_ORG) || (flags & COMP_EDITOR_DELEGATE)|| (flags & COMP_EDITOR_NEW_ITEM))) {
+		if (!((flags & COMP_EDITOR_USER_ORG) || (flags & COMP_EDITOR_DELEGATE)|| (flags & COMP_EDITOR_NEW_ITEM))) {
 			GtkAction *action;
 
 			action = comp_editor_get_action (editor, "free-busy");
@@ -346,7 +346,7 @@ event_editor_dispose (GObject *object)
 	priv = EVENT_EDITOR_GET_PRIVATE (object);
 
 	if (priv->event_page) {
- 		g_object_unref (priv->event_page);
+		g_object_unref (priv->event_page);
 		priv->event_page = NULL;
 	}
 
@@ -551,8 +551,8 @@ event_editor_edit_comp (CompEditor *editor, ECalComponent *comp)
 	/* Set up the attendees */
 	if (attendees != NULL) {
 		GSList *l;
-		int row;
-		char *user_email;
+		gint row;
+		gchar *user_email;
 		user_email = itip_get_comp_attendee (comp, client);
 
 		if (!priv->meeting_shown) {
@@ -639,10 +639,11 @@ event_editor_send_comp (CompEditor *editor, ECalComponentItipMethod method, gboo
 
 		client = e_meeting_store_get_e_cal (priv->model);
 		result = itip_send_comp (E_CAL_COMPONENT_METHOD_CANCEL, comp,
-				client, NULL, NULL, NULL, strip_alarms);
+				client, NULL, NULL, NULL, strip_alarms, FALSE);
 		g_object_unref (comp);
 
-		return result;
+		if (!result)
+			return result;
 	}
 
  parent:
@@ -691,7 +692,7 @@ event_editor_show_meeting (EventEditor *ee)
 
 		ee->priv->meeting_shown = TRUE;
 
- 		comp_editor_set_changed (editor, FALSE);
+		comp_editor_set_changed (editor, FALSE);
 		comp_editor_set_needs_send (editor, TRUE);
 	}
 
