@@ -896,7 +896,7 @@ set_date_label (EItipControl *itip, GtkHTML *html, GtkHTMLStream *html_stream,
 
 	e_cal_component_get_dtstart (comp, &datetime);
 	if (datetime.value) {
-		/* For Translators : 'starts' is starts:date implying a task starts on what date */
+		/* For Translators : 'Starts' is part of "Starts: date", showing when the event starts */
 		str = g_strdup_printf ("<b>%s:</b>", _("Starts"));
 		write_label_piece (itip, &datetime, buffer, str, "<br>", FALSE);
 		gtk_html_write (html, html_stream, buffer->str, buffer->len);
@@ -909,8 +909,8 @@ set_date_label (EItipControl *itip, GtkHTML *html, GtkHTMLStream *html_stream,
 	g_string_truncate (buffer, 0);
 
 	e_cal_component_get_dtend (comp, &datetime);
-	if (datetime.value){
-		/* For Translators : 'ends' is ends:date implying a task ends on what date */
+	if (datetime.value) {
+		/* For Translators : 'Ends' is part of "Ends: date", showing when the event ends */
 		str = g_strdup_printf ("<b>%s:</b>", _("Ends"));
 		write_label_piece (itip, &datetime, buffer, str, "<br>", FALSE);
 		gtk_html_write (html, html_stream, buffer->str, buffer->len);
@@ -2089,7 +2089,7 @@ send_item (EItipControl *itip)
 	comp = get_real_item (itip);
 
 	if (comp != NULL) {
-		itip_send_comp (E_CAL_COMPONENT_METHOD_REQUEST, comp, priv->current_ecal, NULL, NULL, NULL, TRUE);
+		itip_send_comp (E_CAL_COMPONENT_METHOD_REQUEST, comp, priv->current_ecal, NULL, NULL, NULL, TRUE, FALSE);
 		g_object_unref (comp);
 		dialog = gtk_message_dialog_new (
 			NULL, 0,
@@ -2144,7 +2144,7 @@ send_freebusy (EItipControl *itip)
 
 		for (l = comp_list; l; l = l->next) {
 			ECalComponent *comp = E_CAL_COMPONENT (l->data);
-			itip_send_comp (E_CAL_COMPONENT_METHOD_REPLY, comp, priv->current_ecal, NULL, NULL, NULL, TRUE);
+			itip_send_comp (E_CAL_COMPONENT_METHOD_REPLY, comp, priv->current_ecal, NULL, NULL, NULL, TRUE, FALSE);
 
 			g_object_unref (comp);
 		}
@@ -2604,7 +2604,7 @@ ok_clicked_cb (GtkWidget *widget, gpointer data)
 		g_slist_free (list);
 
 		e_cal_component_rescan (comp);
-		itip_send_comp (E_CAL_COMPONENT_METHOD_REPLY, comp, priv->current_ecal, priv->top_level, NULL, NULL, TRUE);
+		itip_send_comp (E_CAL_COMPONENT_METHOD_REPLY, comp, priv->current_ecal, priv->top_level, NULL, NULL, TRUE, FALSE);
 
 		g_object_unref (comp);
 	}
