@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -66,8 +66,8 @@ enum DndTargetType {
 #define PERSONAL_RELATIVE_URI "system"
 
 static GtkTargetEntry drag_types[] = {
-	{ CALENDAR_TYPE, 0, DND_TARGET_TYPE_CALENDAR_LIST },
-	{ XCALENDAR_TYPE, 0, DND_TARGET_TYPE_CALENDAR_LIST }
+	{ (gchar *) CALENDAR_TYPE, 0, DND_TARGET_TYPE_CALENDAR_LIST },
+	{ (gchar *) XCALENDAR_TYPE, 0, DND_TARGET_TYPE_CALENDAR_LIST }
 };
 static gint num_drag_types = sizeof(drag_types) / sizeof(drag_types[0]);
 
@@ -78,7 +78,6 @@ static BonoboObjectClass *parent_class = NULL;
 /* Tasks should have their own registry */
 extern ECompEditorRegistry *comp_editor_registry;
 
-
 typedef struct
 {
 	ESourceList *source_list;
@@ -104,8 +103,8 @@ typedef struct
 } TasksComponentView;
 
 struct _TasksComponentPrivate {
-	char *base_directory;
-	char *config_directory;
+	gchar *base_directory;
+	gchar *config_directory;
 
 	ESourceList *source_list;
 	GSList *source_selection;
@@ -123,7 +122,7 @@ ensure_sources (TasksComponent *component)
 	ESourceList *source_list;
 	ESourceGroup *on_this_computer;
 	ESource *personal_source;
-	char *base_uri, *base_uri_proto, base_uri_proto_seventh;
+	gchar *base_uri, *base_uri_proto, base_uri_proto_seventh;
 	const gchar *base_dir;
 
 	personal_source = NULL;
@@ -243,7 +242,7 @@ is_in_uids (GSList *uids, ESource *source)
 	GSList *l;
 
 	for (l = uids; l; l = l->next) {
-		const char *uid = l->data;
+		const gchar *uid = l->data;
 
 		if (!strcmp (uid, e_source_peek_uid (source)))
 			return TRUE;
@@ -270,7 +269,7 @@ update_uris_for_selection (TasksComponentView *component_view)
 		ESource *selected_source = l->data;
 
 		e_tasks_add_todo_source (component_view->tasks, selected_source);
-		uids_selected = g_slist_append (uids_selected, (char *)e_source_peek_uid (selected_source));
+		uids_selected = g_slist_append (uids_selected, (gchar *)e_source_peek_uid (selected_source));
 	}
 
 	e_source_selector_free_selection (component_view->source_selection);
@@ -326,7 +325,7 @@ update_selection (TasksComponentView *component_view)
 
 	/* Make sure the whole selection is there */
 	for (l = uids_selected; l; l = l->next) {
-		char *uid = l->data;
+		gchar *uid = l->data;
 		ESource *source;
 
 		source = e_source_list_peek_source_by_uid (component_view->source_list, uid);
@@ -342,7 +341,7 @@ static void
 update_primary_selection (TasksComponentView *component_view)
 {
 	ESource *source = NULL;
-	char *uid;
+	gchar *uid;
 
 	uid = calendar_config_get_primary_tasks ();
 	if (uid) {
@@ -362,7 +361,7 @@ update_primary_selection (TasksComponentView *component_view)
 
 /* Callbacks.  */
 static void
-copy_task_list_cb (EPopup *ep, EPopupItem *pitem, void *data)
+copy_task_list_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	TasksComponentView *component_view = data;
 	ESource *selected_source;
@@ -375,12 +374,12 @@ copy_task_list_cb (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-delete_task_list_cb (EPopup *ep, EPopupItem *pitem, void *data)
+delete_task_list_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	TasksComponentView *component_view = data;
 	ESource *selected_source;
 	ECal *cal;
-	char *uri;
+	gchar *uri;
 
 	selected_source = e_source_selector_peek_primary_selection (E_SOURCE_SELECTOR (component_view->source_selector));
 	if (!selected_source)
@@ -414,13 +413,13 @@ delete_task_list_cb (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-new_task_list_cb (EPopup *ep, EPopupItem *pitem, void *data)
+new_task_list_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	calendar_setup_new_task_list (GTK_WINDOW (gtk_widget_get_toplevel(ep->target->widget)));
 }
 
 static void
-rename_task_list_cb (EPopup *ep, EPopupItem *pitem, void *data)
+rename_task_list_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	TasksComponentView *component_view = data;
 	ESourceSelector *selector;
@@ -430,7 +429,7 @@ rename_task_list_cb (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-edit_task_list_cb (EPopup *ep, EPopupItem *pitem, void *data)
+edit_task_list_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	TasksComponentView *component_view = data;
 	ESource *selected_source;
@@ -442,8 +441,8 @@ edit_task_list_cb (EPopup *ep, EPopupItem *pitem, void *data)
 	calendar_setup_edit_task_list (GTK_WINDOW (gtk_widget_get_toplevel(ep->target->widget)), selected_source);
 }
 
-static void 
-set_offline_availability (EPopup *ep, EPopupItem *pitem, void *data, const char *value)
+static void
+set_offline_availability (EPopup *ep, EPopupItem *pitem, gpointer data, const gchar *value)
 {
 	TasksComponentView *component_view = data;
 	ESource *selected_source;
@@ -456,33 +455,33 @@ set_offline_availability (EPopup *ep, EPopupItem *pitem, void *data, const char
 }
 
 static void
-mark_no_offline_cb (EPopup *ep, EPopupItem *pitem, void *data)
+mark_no_offline_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
-	set_offline_availability (ep, pitem, data, "0"); 
+	set_offline_availability (ep, pitem, data, "0");
 }
 
 static void
-mark_offline_cb (EPopup *ep, EPopupItem *pitem, void *data)
+mark_offline_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
-	set_offline_availability (ep, pitem, data, "1"); 
+	set_offline_availability (ep, pitem, data, "1");
 }
 
 static EPopupItem etc_source_popups[] = {
-	{ E_POPUP_ITEM, "10.new", N_("_New Task List"), new_task_list_cb, NULL, "stock_todo", 0, 0 },
-	{ E_POPUP_ITEM, "15.copy", N_("_Copy..."), copy_task_list_cb, NULL, "edit-copy", 0, E_CAL_POPUP_SOURCE_PRIMARY },
-	{ E_POPUP_ITEM, "18.rename", N_("_Rename..."), rename_task_list_cb, NULL, NULL, 0, E_CAL_POPUP_SOURCE_PRIMARY },
+	{ E_POPUP_ITEM, (gchar *) "10.new", (gchar *) N_("_New Task List"), new_task_list_cb, NULL, (gchar *) "stock_todo", 0, 0 },
+	{ E_POPUP_ITEM, (gchar *) "15.copy", (gchar *) N_("_Copy..."), copy_task_list_cb, NULL, (gchar *) "edit-copy", 0, E_CAL_POPUP_SOURCE_PRIMARY },
+	{ E_POPUP_ITEM, (gchar *) "18.rename", (gchar *) N_("_Rename..."), rename_task_list_cb, NULL, NULL, 0, E_CAL_POPUP_SOURCE_PRIMARY },
 
-	{ E_POPUP_BAR, "20.bar" },
-	{ E_POPUP_ITEM, "20.delete", N_("_Delete"), delete_task_list_cb, NULL, "edit-delete", 0, E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY },
-	{ E_POPUP_ITEM, "30.mark_tasks_offline", N_("_Make available for offline use"), mark_offline_cb, NULL, "stock_disconnect", E_CAL_POPUP_SOURCE_OFFLINE, E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY|E_CAL_POPUP_SOURCE_OFFLINE },
-	{ E_POPUP_ITEM, "40.mark_tasks_no_offline", N_("_Do not make available for offline use"), mark_no_offline_cb, NULL, "stock_connect", E_CAL_POPUP_SOURCE_NO_OFFLINE, E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY|E_CAL_POPUP_SOURCE_NO_OFFLINE },
+	{ E_POPUP_BAR, (gchar *) "20.bar" },
+	{ E_POPUP_ITEM, (gchar *) "20.delete", (gchar *) N_("_Delete"), delete_task_list_cb, NULL, (gchar *) "edit-delete", 0, E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY },
+	{ E_POPUP_ITEM, (gchar *) "30.mark_tasks_offline", (gchar *) N_("_Make available for offline use"), mark_offline_cb, NULL, (gchar *) "stock_disconnect", E_CAL_POPUP_SOURCE_OFFLINE, E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY|E_CAL_POPUP_SOURCE_OFFLINE },
+	{ E_POPUP_ITEM, (gchar *) "40.mark_tasks_no_offline", (gchar *) N_("_Do not make available for offline use"), mark_no_offline_cb, NULL, (gchar *) "stock_connect", E_CAL_POPUP_SOURCE_NO_OFFLINE, E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY|E_CAL_POPUP_SOURCE_NO_OFFLINE },
 
-	{ E_POPUP_BAR, "99.bar" },
-	{ E_POPUP_ITEM, "99.properties", N_("_Properties"), edit_task_list_cb, NULL, "document-properties", 0, E_CAL_POPUP_SOURCE_PRIMARY },
+	{ E_POPUP_BAR, (gchar *) "99.bar" },
+	{ E_POPUP_ITEM, (gchar *) "99.properties", (gchar *) N_("_Properties"), edit_task_list_cb, NULL, (gchar *) "document-properties", 0, E_CAL_POPUP_SOURCE_PRIMARY },
 };
 
 static void
-etc_source_popup_free(EPopup *ep, GSList *list, void *data)
+etc_source_popup_free(EPopup *ep, GSList *list, gpointer data)
 {
 	g_slist_free(list);
 }
@@ -493,7 +492,7 @@ popup_event_cb(ESourceSelector *selector, ESource *insource, GdkEventButton *eve
 	ECalPopup *ep;
 	ECalPopupTargetSource *t;
 	GSList *menus = NULL;
-	int i;
+	gint i;
 	GtkMenu *menu;
 
 	/** @HookPoint-ECalPopup: Tasks Source Selector Context Menu
@@ -546,7 +545,7 @@ static void
 set_info (TasksComponentView *component_view)
 {
 	GString *message = g_string_new (NULL);
-	int rows, selected_rows;
+	gint rows, selected_rows;
 
 	rows = e_table_model_row_count (component_view->model);
 	selected_rows =  e_table_selected_count (component_view->table);
@@ -573,13 +572,13 @@ model_changed_cb (ETableModel *etm, TasksComponentView *component_view)
 }
 
 static void
-model_rows_inserted_cb (ETableModel *etm, int row, int count, TasksComponentView *component_view)
+model_rows_inserted_cb (ETableModel *etm, gint row, gint count, TasksComponentView *component_view)
 {
 	set_info (component_view);
 }
 
 static void
-model_rows_deleted_cb (ETableModel *etm, int row, int count, TasksComponentView *component_view)
+model_rows_deleted_cb (ETableModel *etm, gint row, gint count, TasksComponentView *component_view)
 {
 	set_info (component_view);
 }
@@ -631,7 +630,7 @@ selector_tree_data_dropped (ESourceSelector *selector,
 	components = cal_comp_selection_get_string_list (data);
 	success = components != NULL;
 	for (p = components; p && success; p = p->next) {
-		char *comp_str; /* do not free this! */
+		gchar *comp_str; /* do not free this! */
 
 		/* p->data is "source_uid\ncomponent_string" */
 		comp_str = strchr (p->data, '\n');
@@ -690,7 +689,7 @@ setup_create_ecal (TasksComponent *component, TasksComponentView *component_view
 {
 	TasksComponentPrivate *priv;
 	ESource *source = NULL;
-	char *uid;
+	gchar *uid;
 	guint not;
 
 	priv = component->priv;
@@ -761,7 +760,7 @@ setup_create_ecal (TasksComponent *component, TasksComponentView *component_view
 	/* Save the primary source for use elsewhere */
 	calendar_config_set_primary_tasks (e_source_peek_uid (source));
 
-	return priv->create_ecal ;
+	return priv->create_ecal;
 }
 
 /* Ensures the calendar is selected */
@@ -809,7 +808,7 @@ create_new_todo (TasksComponent *task_component, gboolean is_assigned, TasksComp
 }
 
 static void
-create_local_item_cb (EUserCreatableItemsHandler *handler, const char *item_type_name, void *data)
+create_local_item_cb (EUserCreatableItemsHandler *handler, const gchar *item_type_name, gpointer data)
 {
 	TasksComponent *tasks_component = data;
 	TasksComponentPrivate *priv;
@@ -1026,16 +1025,16 @@ impl_createView (PortableServer_Servant servant,
 }
 
 static void
-impl_handleURI (PortableServer_Servant servant, const char *uri, CORBA_Environment *ev)
+impl_handleURI (PortableServer_Servant servant, const gchar *uri, CORBA_Environment *ev)
 {
 	TasksComponent *tasks_component = TASKS_COMPONENT (bonobo_object_from_servant (servant));
 	TasksComponentPrivate *priv;
 	GList *l;
 	TasksComponentView *view = NULL;
 
-	char *src_uid = NULL;
-	char *uid = NULL;
-	char *rid = NULL;
+	gchar *src_uid = NULL;
+	gchar *uid = NULL;
+	gchar *rid = NULL;
 
 	priv = tasks_component->priv;
 
@@ -1047,9 +1046,9 @@ impl_handleURI (PortableServer_Servant servant, const char *uri, CORBA_Environme
 
 	if (!strncmp (uri, "task:", 5)) {
 		EUri *euri = e_uri_new (uri);
-		const char *p;
-		char *header, *content;
-		size_t len, clen;
+		const gchar *p;
+		gchar *header, *content;
+		gsize len, clen;
 
 		p = euri->query;
 		if (p) {
@@ -1060,7 +1059,7 @@ impl_handleURI (PortableServer_Servant servant, const char *uri, CORBA_Environme
 				if (p[len] != '=')
 					break;
 
-				header = (char *) p;
+				header = (gchar *) p;
 				header[len] = '\0';
 				p += len + 1;
 
@@ -1110,28 +1109,28 @@ impl__get_userCreatableItems (PortableServer_Servant servant,
 
 	CORBA_sequence_set_release (list, FALSE);
 
-	list->_buffer[0].id = CREATE_TASK_ID;
-	list->_buffer[0].description = _("New task");
-	list->_buffer[0].menuDescription = (char *) C_("New", "_Task");
-	list->_buffer[0].tooltip = _("Create a new task");
+	list->_buffer[0].id = (gchar *) CREATE_TASK_ID;
+	list->_buffer[0].description = (gchar *) _("New task");
+	list->_buffer[0].menuDescription = (gchar *) C_("New", "_Task");
+	list->_buffer[0].tooltip = (gchar *) _("Create a new task");
 	list->_buffer[0].menuShortcut = 't';
-	list->_buffer[0].iconName = "stock_task";
+	list->_buffer[0].iconName = (gchar *) "stock_task";
 	list->_buffer[0].type = GNOME_Evolution_CREATABLE_OBJECT;
 
-	list->_buffer[1].id = CREATE_TASK_ASSIGNED_ID;
-	list->_buffer[1].description = _("New assigned task");
-	list->_buffer[1].menuDescription = (char *) C_("New", "Assigne_d Task");
-	list->_buffer[1].tooltip = _("Create a new assigned task");
+	list->_buffer[1].id = (gchar *) CREATE_TASK_ASSIGNED_ID;
+	list->_buffer[1].description = (gchar *) _("New assigned task");
+	list->_buffer[1].menuDescription = (gchar *) C_("New", "Assigne_d Task");
+	list->_buffer[1].tooltip = (gchar *) _("Create a new assigned task");
 	list->_buffer[1].menuShortcut = '\0';
-	list->_buffer[1].iconName = "stock_task";
+	list->_buffer[1].iconName = (gchar *) "stock_task";
 	list->_buffer[1].type = GNOME_Evolution_CREATABLE_OBJECT;
 
-	list->_buffer[2].id = CREATE_TASK_LIST_ID;
-	list->_buffer[2].description = _("New task list");
-	list->_buffer[2].menuDescription = (char *) C_("New", "Tas_k list");
-	list->_buffer[2].tooltip = _("Create a new task list");
+	list->_buffer[2].id = (gchar *) CREATE_TASK_LIST_ID;
+	list->_buffer[2].description = (gchar *) _("New task list");
+	list->_buffer[2].menuDescription = (gchar *) C_("New", "Tas_k list");
+	list->_buffer[2].tooltip = (gchar *) _("Create a new task list");
 	list->_buffer[2].menuShortcut = '\0';
-	list->_buffer[2].iconName = "stock_todo";
+	list->_buffer[2].iconName = (gchar *) "stock_todo";
 	list->_buffer[2].type = GNOME_Evolution_CREATABLE_FOLDER;
 
 	return list;
@@ -1273,13 +1272,13 @@ tasks_component_peek (void)
 	return component;
 }
 
-const char *
+const gchar *
 tasks_component_peek_base_directory (TasksComponent *component)
 {
 	return component->priv->base_directory;
 }
 
-const char *
+const gchar *
 tasks_component_peek_config_directory (TasksComponent *component)
 {
 	return component->priv->config_directory;
