@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -35,10 +35,10 @@
 
 #define d(x)
 
-static int validate(FilterRule *fr);
-static int filter_eq(FilterRule *fr, FilterRule *cm);
+static gint validate(FilterRule *fr);
+static gint filter_eq(FilterRule *fr, FilterRule *cm);
 static xmlNodePtr xml_encode(FilterRule *fr);
-static int xml_decode(FilterRule *fr, xmlNodePtr, RuleContext *rc);
+static gint xml_decode(FilterRule *fr, xmlNodePtr, RuleContext *rc);
 static void rule_copy(FilterRule *dest, FilterRule *src);
 /*static void build_code(FilterRule *, GString *out);*/
 static GtkWidget *get_widget(FilterRule *fr, RuleContext *rc);
@@ -171,12 +171,12 @@ em_filter_rule_build_action(EMFilterRule *fr, GString *out)
 	g_string_append(out, ")\n");
 }
 
-static int
+static gint
 validate(FilterRule *fr)
 {
 	EMFilterRule *ff =(EMFilterRule *)fr;
 	GList *parts;
-	int valid;
+	gint valid;
 
         valid = FILTER_RULE_CLASS(parent_class)->validate(fr);
 
@@ -190,10 +190,10 @@ validate(FilterRule *fr)
 	return valid;
 }
 
-static int
+static gint
 list_eq(GList *al, GList *bl)
 {
-	int truth = TRUE;
+	gint truth = TRUE;
 
 	while (truth && al && bl) {
 		FilterPart *a = al->data, *b = bl->data;
@@ -206,7 +206,7 @@ list_eq(GList *al, GList *bl)
 	return truth && al == NULL && bl == NULL;
 }
 
-static int
+static gint
 filter_eq(FilterRule *fr, FilterRule *cm)
 {
         return FILTER_RULE_CLASS(parent_class)->eq(fr, cm)
@@ -222,7 +222,7 @@ xml_encode(FilterRule *fr)
 
         node = FILTER_RULE_CLASS(parent_class)->xml_encode(fr);
 	g_return_val_if_fail (node != NULL, NULL);
-	set = xmlNewNode(NULL, (const unsigned char *)"actionset");
+	set = xmlNewNode(NULL, (const guchar *)"actionset");
 	xmlAddChild(node, set);
 	l = ff->actions;
 	while (l) {
@@ -239,13 +239,13 @@ static void
 load_set(xmlNodePtr node, EMFilterRule *ff, RuleContext *rc)
 {
 	xmlNodePtr work;
-	char *rulename;
+	gchar *rulename;
 	FilterPart *part;
 
 	work = node->children;
 	while (work) {
-		if (!strcmp((char *)work->name, "part")) {
-			rulename = (char *)xmlGetProp(work, (const unsigned char *)"name");
+		if (!strcmp((gchar *)work->name, "part")) {
+			rulename = (gchar *)xmlGetProp(work, (const guchar *)"name");
 			part = em_filter_context_find_action((EMFilterContext *)rc, rulename);
 			if (part) {
 				part = filter_part_clone(part);
@@ -262,12 +262,12 @@ load_set(xmlNodePtr node, EMFilterRule *ff, RuleContext *rc)
 	}
 }
 
-static int
+static gint
 xml_decode(FilterRule *fr, xmlNodePtr node, RuleContext *rc)
 {
 	EMFilterRule *ff =(EMFilterRule *)fr;
 	xmlNodePtr work;
-	int result;
+	gint result;
 
         result = FILTER_RULE_CLASS(parent_class)->xml_decode(fr, node, rc);
 	if (result != 0)
@@ -275,7 +275,7 @@ xml_decode(FilterRule *fr, xmlNodePtr node, RuleContext *rc)
 
 	work = node->children;
 	while (work) {
-		if (!strcmp((char *)work->name, "actionset")) {
+		if (!strcmp((gchar *)work->name, "actionset")) {
 			load_set(work, ff, rc);
 		}
 		work = work->next;
@@ -324,42 +324,47 @@ struct _part_data {
 };
 
 static void
-option_activate(GtkMenuItem *item, struct _part_data *data)
+part_combobox_changed (GtkComboBox *combobox, struct _part_data *data)
 {
-	FilterPart *part = g_object_get_data((GObject *)item, "part");
+	FilterPart *part = NULL;
 	FilterPart *newpart;
+	gint index, i;
+
+	index = gtk_combo_box_get_active (combobox);
+	for (i = 0, part = em_filter_context_next_action (data->f, part); part && i < index; i++, part = em_filter_context_next_action (data->f, part)) {
+		/* traverse until reached index */
+	}
+
+	g_return_if_fail (part != NULL);
+	g_return_if_fail (i == index);
 
 	/* dont update if we haven't changed */
-	if (!strcmp(part->title, data->part->title))
+	if (!strcmp (part->title, data->part->title))
 		return;
 
 	/* here we do a widget shuffle, throw away the old widget/rulepart,
 	   and create another */
 	if (data->partwidget)
-		gtk_container_remove(GTK_CONTAINER(data->container), data->partwidget);
+		gtk_container_remove (GTK_CONTAINER (data->container), data->partwidget);
 
-	newpart = filter_part_clone(part);
-	filter_part_copy_values(newpart, data->part);
-	em_filter_rule_replace_action((EMFilterRule *)data->fr, data->part, newpart);
-	g_object_unref(data->part);
+	newpart = filter_part_clone (part);
+	filter_part_copy_values (newpart, data->part);
+	em_filter_rule_replace_action ((EMFilterRule *)data->fr, data->part, newpart);
+	g_object_unref (data->part);
 	data->part = newpart;
-	data->partwidget = filter_part_get_widget(newpart);
+	data->partwidget = filter_part_get_widget (newpart);
 	if (data->partwidget)
-		gtk_box_pack_start(GTK_BOX(data->container), data->partwidget, TRUE, TRUE, 0);
-
-	g_object_set_data((GObject *)data->container, "part", newpart);
+		gtk_box_pack_start (GTK_BOX (data->container), data->partwidget, TRUE, TRUE, 0);
 }
 
 static GtkWidget *
 get_rule_part_widget(EMFilterContext *f, FilterPart *newpart, FilterRule *fr)
 {
 	FilterPart *part = NULL;
-	GtkWidget *menu;
-	GtkWidget *item;
-	GtkWidget *omenu;
+	GtkWidget *combobox;
 	GtkWidget *hbox;
 	GtkWidget *p;
-	int index = 0, current = 0;
+	gint index = 0, current = 0;
 	struct _part_data *data;
 
 	data = g_malloc0(sizeof(*data));
@@ -373,14 +378,9 @@ get_rule_part_widget(EMFilterContext *f, FilterPart *newpart, FilterRule *fr)
 	data->partwidget = p;
 	data->container = hbox;
 
-	menu = gtk_menu_new();
+	combobox = gtk_combo_box_new_text ();
 	while ((part = em_filter_context_next_action(f, part))) {
-		item = gtk_menu_item_new_with_label(_(part->title));
-
-		g_object_set_data((GObject *)item, "part", part);
-		g_signal_connect(item, "activate", G_CALLBACK(option_activate), data);
-		gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
-		gtk_widget_show(item);
+		gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _(part->title));
 
 		if (!strcmp(newpart->title, part->title))
 			current = index;
@@ -388,12 +388,11 @@ get_rule_part_widget(EMFilterContext *f, FilterPart *newpart, FilterRule *fr)
 		index++;
 	}
 
-	omenu = gtk_option_menu_new();
-	gtk_option_menu_set_menu(GTK_OPTION_MENU(omenu), menu);
-	gtk_option_menu_set_history(GTK_OPTION_MENU(omenu), current);
-	gtk_widget_show(omenu);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), current);
+	g_signal_connect (combobox, "changed", G_CALLBACK (part_combobox_changed), data);
+	gtk_widget_show (combobox);
 
-	gtk_box_pack_start(GTK_BOX(hbox), omenu, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(hbox), combobox, FALSE, FALSE, 0);
 	if (p)
 		gtk_box_pack_start(GTK_BOX(hbox), p, TRUE, TRUE, 0);
 
@@ -432,7 +431,7 @@ less_parts(GtkWidget *button, struct _rule_data *data)
 }
 
 static void
-attach_rule(GtkWidget *rule, struct _rule_data *data, FilterPart *part, int row)
+attach_rule(GtkWidget *rule, struct _rule_data *data, FilterPart *part, gint row)
 {
 	GtkWidget *remove;
 
@@ -497,7 +496,7 @@ more_parts(GtkWidget *button, struct _rule_data *data)
 			adjustment = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (w));
 			if (adjustment)
 				gtk_adjustment_set_value (adjustment, adjustment->upper);
-				
+
 		}
 	}
 }
@@ -513,7 +512,7 @@ get_widget(FilterRule *fr, RuleContext *rc)
 	FilterPart *part;
 	struct _rule_data *data;
 	EMFilterRule *ff =(EMFilterRule *)fr;
-	int rows, i = 0;
+	gint rows, i = 0;
 	gchar *msg;
 
         widget = FILTER_RULE_CLASS(parent_class)->get_widget(fr, rc);
