@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -24,29 +24,27 @@
 #ifndef EM_INLINE_FILTER_H
 #define EM_INLINE_FILTER_H
 
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
+#include <camel/camel-mime-filter.h>
+#include <camel/camel-mime-utils.h>
+#include <camel/camel-multipart.h>
 
 #define EM_INLINE_FILTER_TYPE     (em_inline_filter_get_type ())
 #define EM_INLINE_FILTER(obj)     (CAMEL_CHECK_CAST((obj), EM_INLINE_FILTER_TYPE, EMInlineFilter))
 #define EM_INLINE_FILTER_CLASS(k) (CAMEL_CHECK_CLASS_CAST ((k), EM_INLINE_FILTER_TYPE, EMInlineFilterClass))
 #define EM_IS_INLINE_FILTER(o)    (CAMEL_CHECK_TYPE((o), EM_INLINE_FILTER_TYPE))
 
-#include <camel/camel-mime-filter.h>
-#include <camel/camel-mime-utils.h>
+G_BEGIN_DECLS
 
 typedef struct _EMInlineFilter {
 	CamelMimeFilter filter;
 
-	int state;
+	gint state;
 
 	CamelTransferEncoding base_encoding;
 	CamelContentType *base_type;
 
 	GByteArray *data;
-	char *filename;
+	gchar *filename;
 	GSList *parts;
 } EMInlineFilter;
 
@@ -56,10 +54,8 @@ typedef struct _EMInlineFilterClass {
 
 CamelType    em_inline_filter_get_type(void);
 EMInlineFilter *em_inline_filter_new(CamelTransferEncoding base_encoding, CamelContentType *type);
-struct _CamelMultipart *em_inline_filter_get_multipart(EMInlineFilter *emif);
+CamelMultipart *em_inline_filter_get_multipart(EMInlineFilter *emif);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* EM_INLINE_FILTER_H */
