@@ -414,6 +414,25 @@ folder_selected_cb (EMFolderTree *emft, const gchar *path, const gchar *uri, gui
 	}
 }
 
+static void
+tree_hidden_key_event_cb (EMFolderTree *emft, GdkEvent *event, EMFolderView *view)
+{
+	if (event && event->type == GDK_KEY_PRESS && view && view->list) {
+		switch (event->key.keyval) {
+		case '[':
+		case ',':
+			gtk_widget_grab_focus ((GtkWidget *) view->list);
+			message_list_select (view->list, MESSAGE_LIST_SELECT_PREVIOUS|MESSAGE_LIST_SELECT_WRAP, 0, CAMEL_MESSAGE_SEEN);
+			break;
+		case ']':
+		case '.':
+			gtk_widget_grab_focus ((GtkWidget *) view->list);
+			message_list_select (view->list, MESSAGE_LIST_SELECT_NEXT|MESSAGE_LIST_SELECT_WRAP, 0, CAMEL_MESSAGE_SEEN);
+			break;
+		}
+	}
+}
+
 static gint
 check_autosave(gpointer data)
 {
@@ -694,7 +713,10 @@ enable_folder_tree (GtkWidget *emfb, GtkWidget *emft)
 
 	/* Get the selected folder in the folder tree. */
 	selected_folder = em_folder_tree_get_selected_folder(EM_FOLDER_TREE (emft));
-	uri = mail_tools_folder_to_url (selected_folder);
+	if (selected_folder)
+		uri = mail_tools_folder_to_url (selected_folder);
+	else
+		uri = NULL;
 
 	selected_curl = uri ? camel_url_new (uri, NULL) : NULL;
 
@@ -783,9 +805,9 @@ impl_createView (PortableServer_Servant servant,
 			       e_user_creatable_items_handler_new("mail", create_local_item_cb, tree_widget),
 			       (GDestroyNotify)g_object_unref);
 
-
 	g_signal_connect (component_view->view_control, "activate", G_CALLBACK (view_control_activate_cb), view_widget);
 	g_signal_connect (tree_widget, "folder-selected", G_CALLBACK (folder_selected_cb), view_widget);
+	g_signal_connect (tree_widget, "hidden-key-event", G_CALLBACK (tree_hidden_key_event_cb), view_widget);
 
 	g_signal_connect((EMFolderBrowser *)view_widget, "account_search_cleared", G_CALLBACK (enable_folder_tree), tree_widget);
 	g_signal_connect(((EMFolderBrowser *)view_widget), "account_search_activated", G_CALLBACK (disable_folder_tree), tree_widget);
@@ -1359,7 +1381,7 @@ mail_component_peek_activity_handler (MailComponent *component)
 	return component->priv->activity_handler;
 }
 
-struct _CamelSession *mail_component_peek_session(MailComponent *component)
+CamelSession *mail_component_peek_session(MailComponent *component)
 {
 	MAIL_COMPONENT_DEFAULT(component);
 
@@ -1546,7 +1568,7 @@ mail_component_peek_local_store (MailComponent *mc)
  *
  * Return value:
  **/
-struct _CamelFolder *
+CamelFolder *
 mail_component_get_folder(MailComponent *mc, enum _mail_component_folder_t id)
 {
 	g_return_val_if_fail (id <= MAIL_COMPONENT_FOLDER_LOCAL_INBOX, NULL);
@@ -1606,4 +1628,13 @@ mail_component_show_logger (gpointer top)
 	eni_show_logger(logger, top, MAILER_ERROR_TIME_OUT_KEY, MAILER_ERROR_LEVEL_KEY);
 }
 
+void
+mail_component_show_status_bar (gboolean show)
+{
+	/*MailComponent *mc = mail_component_peek ();*/
+
+	/* Nothing to do */
+	return;
+}
+
 BONOBO_TYPE_FUNC_FULL (MailComponent, GNOME_Evolution_MailComponent, PARENT_TYPE, mail_component)
