@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -35,7 +35,7 @@
 
 struct _JunkEntry {
 	EGwJunkEntry *entry;
-	int flag;
+	gint flag;
 };
 
 typedef struct _JunkEntry JunkEntry;
@@ -48,7 +48,6 @@ static void free_all(JunkSettings *js);
 static void get_junk_list (JunkSettings *js);
 static void disable_clicked (GtkRadioButton *button, JunkSettings *js);
 static void enable_clicked (GtkRadioButton *button, JunkSettings *js);
-GType junk_settings_get_type (void);
 
 static GtkVBoxClass *parent_class = NULL;
 
@@ -116,7 +115,7 @@ junk_settings_init (JunkSettings *js)
 static void
 free_entry_node(EGwJunkEntry *entry)
 {
-	if(entry){
+	if (entry) {
 		g_free(entry->match);
 		entry->match = NULL;
 	}
@@ -129,7 +128,7 @@ free_node(JunkEntry *nentry)
 {
 	EGwJunkEntry *junk_entry = nentry->entry;
 
-	if(junk_entry){
+	if (junk_entry) {
 		g_free(junk_entry->match);
 		junk_entry->match = NULL;
 	}
@@ -143,15 +142,15 @@ find_node(GList *list, gchar *match)
 	JunkEntry *one_entry = NULL;
 	EGwJunkEntry *ent = NULL;
 	GList *tmp;
-	gint i ;
+	gint i;
 
-	if(list){
+	if (list) {
 		tmp = g_list_first(list);
-		for(i=0; tmp  ; i++)
+		for (i=0; tmp; i++)
 		{
 			one_entry = tmp->data;
 			ent = one_entry->entry;
-			if(!g_ascii_strcasecmp(ent->match, match)){
+			if (!g_ascii_strcasecmp(ent->match, match)) {
 				return one_entry;
 	/*if found, it returns that user*/
 			}
@@ -165,7 +164,7 @@ find_node(GList *list, gchar *match)
 static void
 free_all (JunkSettings *js)
 {
-	if (js->junk_list){
+	if (js->junk_list) {
 		g_list_foreach (js->junk_list,(GFunc) free_node, NULL);
 		g_list_free (js->junk_list);
 		js->junk_list = NULL;
@@ -176,9 +175,9 @@ static void
 get_junk_list (JunkSettings *js)
 {
 	GList *list = NULL;
-	char *entry;
-	char *msg;
-	int use_junk, use_block, use_pab, persistence;
+	gchar *entry;
+	gchar *msg;
+	gint use_junk, use_block, use_pab, persistence;
 
 	if (E_IS_GW_CONNECTION (js->cnc)) {
 		if (e_gw_connection_get_junk_settings (js->cnc, &use_junk, &use_block, &use_pab, &persistence) == E_GW_CONNECTION_STATUS_OK) {
@@ -228,7 +227,7 @@ commit_changes (JunkSettings *js)
 	GList *node = NULL;
 	JunkEntry *junk_entry = NULL;
 	EGwJunkEntry *entry;
-	int use_junk, use_pab, use_block, persistence;
+	gint use_junk, use_pab, use_block, persistence;
 
 	for (node = js->junk_list; node; node = node->next)
 	{
@@ -241,36 +240,44 @@ commit_changes (JunkSettings *js)
 	}
 
 	if (E_IS_GW_CONNECTION (js->cnc)) {
-		if(js->flag_for_ok == 2 && js->enabled){  /* just turn off the bits*/
+		if (js->flag_for_ok == 2 && js->enabled){  /* just turn off the bits*/
 			use_junk = use_pab = use_block = persistence = 0;
-			if (e_gw_connection_modify_junk_settings (js->cnc, use_junk, use_pab, use_block, persistence) == E_GW_CONNECTION_STATUS_OK);
+			if (e_gw_connection_modify_junk_settings (js->cnc, use_junk, use_pab, use_block, persistence) == E_GW_CONNECTION_STATUS_OK) {
+				;
+			}
 
 		}
 		if (js->flag_for_ok == 0 && !js->enabled) {
 			use_block = use_pab =0;
 			use_junk = 1;
 			persistence = 14; /* We are setting the default persistence*/
-			if (e_gw_connection_modify_junk_settings (js->cnc, use_junk, use_pab, use_block, persistence) == E_GW_CONNECTION_STATUS_OK);
+			if (e_gw_connection_modify_junk_settings (js->cnc, use_junk, use_pab, use_block, persistence) == E_GW_CONNECTION_STATUS_OK) {
+				;
+			}
 		}
 
 		while (new_list) {
 			entry = new_list->data;
-			if (e_gw_connection_create_junk_entry (js->cnc, entry->match, "email", "junk") == E_GW_CONNECTION_STATUS_OK);
+			if (e_gw_connection_create_junk_entry (js->cnc, entry->match, "email", "junk") == E_GW_CONNECTION_STATUS_OK) {
+				;
+			}
 			new_list = new_list->next;
 		}
 		while (remove_list) {
 			entry = remove_list->data;
-			if (e_gw_connection_remove_junk_entry (js->cnc, entry->id) == E_GW_CONNECTION_STATUS_OK);
+			if (e_gw_connection_remove_junk_entry (js->cnc, entry->id) == E_GW_CONNECTION_STATUS_OK) {
+				;
+			}
 			remove_list = remove_list->next;
 		}
 
 	}
-	if(new_list){
+	if (new_list) {
 		g_list_foreach (new_list, (GFunc) free_entry_node, NULL);
 		g_list_free (new_list);
 	}
 	new_list = NULL;
-	if(remove_list){
+	if (remove_list) {
 		g_list_foreach (remove_list,(GFunc) free_entry_node, NULL);
 		g_list_free (remove_list);
 	}
@@ -294,8 +301,8 @@ disable_clicked (GtkRadioButton *button, JunkSettings *js)
 static void
 add_clicked(GtkButton *button, JunkSettings *js)
 {
-	const char *email = NULL;
-	const char *self_email = NULL;
+	const gchar *email = NULL;
+	const gchar *self_email = NULL;
 	JunkEntry *new_entry = NULL;
 	EGwJunkEntry *junk_entry = NULL;
 	gchar *msg = NULL;
@@ -307,7 +314,7 @@ add_clicked(GtkButton *button, JunkSettings *js)
 		       return;
 		else {
 			/*check whether already exists*/
-			if (js->junk_list && email){
+			if (js->junk_list && email) {
 				new_entry = find_node (js->junk_list, (gchar *)email);
 				if (new_entry)
 					return;
@@ -348,14 +355,13 @@ remove_clicked(GtkButton *button, JunkSettings *js)
 	gtk_list_store_remove (GTK_LIST_STORE (js->model), &(js->iter));
 }
 
-
 static void
 user_selected(GtkTreeSelection *selection, JunkSettings *js)
 {
 	GtkTreeModel *model;
 
 	gtk_tree_selection_set_mode(selection, GTK_SELECTION_SINGLE);
-	if (gtk_tree_selection_get_selected (selection, &model, &(js->iter))){
+	if (gtk_tree_selection_get_selected (selection, &model, &(js->iter))) {
 		gtk_widget_set_sensitive (GTK_WIDGET (js->remove), TRUE);
 
 	}
@@ -365,7 +371,7 @@ static void
 junk_settings_construct (JunkSettings *js)
 {
 	GladeXML *xml;
-	char *gladefile;
+	gchar *gladefile;
 
 	gladefile = g_build_filename (EVOLUTION_GLADEDIR,
 				      "junk-settings.glade",
@@ -431,4 +437,3 @@ junk_settings_new (EGwConnection *ccnc)
 	return (JunkSettings *) new;
 }
 
-
