@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -38,22 +38,22 @@
 #define ACCOUNT_DISABLE 0
 #define PROXY_LOGOUT 1
 
-void mail_account_disable (EPopup *ep, EPopupItem *p, void *data);
+void mail_account_disable (EPopup *ep, EPopupItem *p, gpointer data);
 void org_gnome_create_mail_account_disable (EPlugin *ep, EMPopupTargetFolder *t);
 
 static EPopupItem popup_items[] = {
-	{ E_POPUP_ITEM, "40.emc.04", N_("_Disable"), mail_account_disable, NULL, NULL, 0, EM_POPUP_FOLDER_STORE },
-	{ E_POPUP_ITEM, "40.emc.04", N_("Proxy _Logout"), mail_account_disable, NULL, NULL, 0, EM_POPUP_FOLDER_STORE }
+	{ E_POPUP_ITEM, (gchar *) "40.emc.04", (gchar *) N_("_Disable"), mail_account_disable, NULL, NULL, 0, EM_POPUP_FOLDER_STORE },
+	{ E_POPUP_ITEM, (gchar *) "40.emc.04", (gchar *) N_("Proxy _Logout"), mail_account_disable, NULL, NULL, 0, EM_POPUP_FOLDER_STORE }
 };
 
 static void
-popup_free (EPopup *ep, GSList *items, void *data)
+popup_free (EPopup *ep, GSList *items, gpointer data)
 {
 	g_slist_free (items);
 }
 
 void
-mail_account_disable (EPopup *ep, EPopupItem *p, void *data)
+mail_account_disable (EPopup *ep, EPopupItem *p, gpointer data)
 {
 	MailComponent *component;
 	EAccount *account = data;
