@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -59,7 +59,7 @@ evolution_listener_init(EvolutionListener *emf, EvolutionListenerClass *klass)
 BONOBO_TYPE_FUNC_FULL (EvolutionListener, GNOME_Evolution_Listener, PARENT_TYPE, evolution_listener)
 
 EvolutionListener *
-evolution_listener_new(EvolutionListenerFunc complete, void *data)
+evolution_listener_new(EvolutionListenerFunc complete, gpointer data)
 {
 	EvolutionListener *el;
 
