@@ -1,22 +1,22 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* killev.c
- *
- * Copyright (C) 2003 Ximian, Inc.
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -35,7 +35,7 @@
 #include <libgnome/gnome-util.h>
 
 typedef struct {
-	char *location;
+	gchar *location;
 	GPtrArray *names;
 } KillevComponent;
 
@@ -43,10 +43,10 @@ static GSList *languages = NULL;
 static GHashTable *components;
 
 static gboolean
-kill_process (const char *proc_name, KillevComponent *comp)
+kill_process (const gchar *proc_name, KillevComponent *comp)
 {
-	int status, i;
-	char *command;
+	gint status, i;
+	gchar *command;
 	GString *desc;
 
 	command = g_strdup_printf (KILL_PROCESS_CMD " -0 %s 2> /dev/null",
@@ -59,7 +59,7 @@ kill_process (const char *proc_name, KillevComponent *comp)
 		 * found, so just bail completely.
 		 */
 		fprintf (stderr, _("Could not execute '%s': %s\n"),
-			 KILL_PROCESS_CMD, strerror (errno));
+			 KILL_PROCESS_CMD, g_strerror (errno));
 		exit (1);
 	}
 
@@ -82,16 +82,16 @@ kill_process (const char *proc_name, KillevComponent *comp)
 	return TRUE;
 }
 
-static const char *patterns[] = {
-	"%s", "%.16s", "lt-%s", "lt-%.13s"
+static const gchar *patterns[] = {
+	"%s", "%.16s", "lt-%s", "lt-%.13s", "%s.bin"
 };
-static const int n_patterns = G_N_ELEMENTS (patterns);
+static const gint n_patterns = G_N_ELEMENTS (patterns);
 
 static void
 kill_component (KillevComponent *comp)
 {
-	char *base_name, *exe_name, *dash;
-	int i;
+	gchar *base_name, *exe_name, *dash;
+	gint i;
 
 	base_name = g_strdup (comp->location);
  try_again:
@@ -115,14 +115,14 @@ kill_component (KillevComponent *comp)
 }
 
 static void
-add_matching_query (const char *query)
+add_matching_query (const gchar *query)
 {
 	Bonobo_ServerInfoList *info_list;
 	Bonobo_ServerInfo *info;
 	CORBA_Environment ev;
-	const char *location, *name;
+	const gchar *location, *name;
 	KillevComponent *comp;
-	int i;
+	gint i;
 
 	CORBA_exception_init (&ev);
 
@@ -162,9 +162,9 @@ add_matching_query (const char *query)
 }
 
 static void
-add_matching_repo_id (const char *repo_id)
+add_matching_repo_id (const gchar *repo_id)
 {
-	char *query;
+	gchar *query;
 
 	query = g_strdup_printf ("repo_ids.has ('%s')", repo_id);
 	add_matching_query (query);
@@ -172,17 +172,17 @@ add_matching_repo_id (const char *repo_id)
 }
 
 static void
-add_matching_iid (const char *iid)
+add_matching_iid (const gchar *iid)
 {
-	char *query;
+	gchar *query;
 
 	query = g_strdup_printf ("iid == '%s'", iid);
 	add_matching_query (query);
 	g_free (query);
 }
 
-int
-main (int argc, char **argv)
+gint
+main (gint argc, gchar **argv)
 {
 	const gchar * const *language_names;
 
